[pal-cvs 3561] [1295] replaced telephone_number with telephone.

Back to archive index

svnno****@sourc***** svnno****@sourc*****
2008年 11月 6日 (木) 21:42:11 JST


Revision: 1295
          http://svn.sourceforge.jp/cgi-bin/viewcvs.cgi?root=pal&view=rev&rev=1295
Author:   shinsuke
Date:     2008-11-06 21:42:11 +0900 (Thu, 06 Nov 2008)

Log Message:
-----------
replaced telephone_number with telephone.

Modified Paths:
--------------
    timecard/trunk/src/main/config/erd/timecard.erd
    timecard/trunk/src/main/config/sql/timecard.ddl
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsbhv/BsUserInfoBhv.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsdao/BsUserInfoDao.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsDailyReport.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsEmployee.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsMonthlyReport.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsUserInfo.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/dbmeta/UserInfoDbm.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/bs/BsUserInfoCB.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsDailyReportCQ.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsEmployeeCQ.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsMonthlyReportCQ.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsUserInfoCQ.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/BsUserInfoCQ.java
    timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/ciq/UserInfoCIQ.java
    timecard/trunk/src/main/webapp/WEB-INF/db/timecard.1.log.db
    timecard/trunk/src/main/webapp/WEB-INF/db/timecard.data.db


-------------- next part --------------
Modified: timecard/trunk/src/main/config/erd/timecard.erd
===================================================================
--- timecard/trunk/src/main/config/erd/timecard.erd	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/config/erd/timecard.erd	2008-11-06 12:42:11 UTC (rev 1295)
@@ -569,9 +569,14 @@
                       <defaultValue></defaultValue>
                     </net.java.amateras.db.visual.model.ColumnModel>
                     <net.java.amateras.db.visual.model.ColumnModel>
-                      <columnName>telephone_number</columnName>
-                      <logicalName>Telephone Number</logicalName>
-                      <columnType class="net.java.amateras.db.dialect.ColumnType" reference="../../net.java.amateras.db.visual.model.ColumnModel[2]/columnType"/>
+                      <columnName>telephone</columnName>
+                      <logicalName>Telephone</logicalName>
+                      <columnType class="net.java.amateras.db.dialect.ColumnType">
+                        <name>VARCHAR</name>
+                        <logicalName>String</logicalName>
+                        <supportSize>true</supportSize>
+                        <type>12</type>
+                      </columnType>
                       <size>40</size>
                       <notNull>false</notNull>
                       <primaryKey>false</primaryKey>

Modified: timecard/trunk/src/main/config/sql/timecard.ddl
===================================================================
--- timecard/trunk/src/main/config/sql/timecard.ddl	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/config/sql/timecard.ddl	2008-11-06 12:42:11 UTC (rev 1295)
@@ -55,7 +55,7 @@
   family_name_desc VARCHAR(100),
   email VARCHAR(255),
   url VARCHAR(255),
-  telephone_number VARCHAR(40),
+  telephone VARCHAR(40),
   role_id VARCHAR(255),
   group_id VARCHAR(255),
   created_time TIMESTAMP NOT NULL,

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsbhv/BsUserInfoBhv.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsbhv/BsUserInfoBhv.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsbhv/BsUserInfoBhv.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -33,7 +33,7 @@
  *     USER_ID
  * 
  * [column]
- *     USER_ID, GIVEN_NAME, FAMILY_NAME, MIDDLE_NAME, GIVEN_NAME_DESC, FAMILY_NAME_DESC, EMAIL, URL, TELEPHONE_NUMBER, ROLE_ID, GROUP_ID, CREATED_TIME, CREATED_BY, UPDATED_TIME, UPDATED_BY, DELETED_TIME, DELETED_BY, VERSIONNO
+ *     USER_ID, GIVEN_NAME, FAMILY_NAME, MIDDLE_NAME, GIVEN_NAME_DESC, FAMILY_NAME_DESC, EMAIL, URL, TELEPHONE, ROLE_ID, GROUP_ID, CREATED_TIME, CREATED_BY, UPDATED_TIME, UPDATED_BY, DELETED_TIME, DELETED_BY, VERSIONNO
  * 
  * [sequence]
  *     

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsdao/BsUserInfoDao.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsdao/BsUserInfoDao.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsdao/BsUserInfoDao.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -20,11 +20,11 @@
 
     public int getCountAll();
 
-    public static final String getListAll_SQL = "select USER_ID, GIVEN_NAME, FAMILY_NAME, MIDDLE_NAME, GIVEN_NAME_DESC, FAMILY_NAME_DESC, EMAIL, URL, TELEPHONE_NUMBER, ROLE_ID, GROUP_ID, CREATED_TIME, CREATED_BY, UPDATED_TIME, UPDATED_BY, DELETED_TIME, DELETED_BY, VERSIONNO from USER_INFO";
+    public static final String getListAll_SQL = "select USER_ID, GIVEN_NAME, FAMILY_NAME, MIDDLE_NAME, GIVEN_NAME_DESC, FAMILY_NAME_DESC, EMAIL, URL, TELEPHONE, ROLE_ID, GROUP_ID, CREATED_TIME, CREATED_BY, UPDATED_TIME, UPDATED_BY, DELETED_TIME, DELETED_BY, VERSIONNO from USER_INFO";
 
     public java.util.List<UserInfo> getListAll();
 
-    public static final String getEntity_SQL = "select USER_ID, GIVEN_NAME, FAMILY_NAME, MIDDLE_NAME, GIVEN_NAME_DESC, FAMILY_NAME_DESC, EMAIL, URL, TELEPHONE_NUMBER, ROLE_ID, GROUP_ID, CREATED_TIME, CREATED_BY, UPDATED_TIME, UPDATED_BY, DELETED_TIME, DELETED_BY, VERSIONNO from USER_INFO where USER_INFO.USER_ID = /*userId*/null";
+    public static final String getEntity_SQL = "select USER_ID, GIVEN_NAME, FAMILY_NAME, MIDDLE_NAME, GIVEN_NAME_DESC, FAMILY_NAME_DESC, EMAIL, URL, TELEPHONE, ROLE_ID, GROUP_ID, CREATED_TIME, CREATED_BY, UPDATED_TIME, UPDATED_BY, DELETED_TIME, DELETED_BY, VERSIONNO from USER_INFO where USER_INFO.USER_ID = /*userId*/null";
 
     public static final String getEntity_ARGS = "userId";
 

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsDailyReport.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsDailyReport.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsDailyReport.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -70,7 +70,7 @@
     /**
      * The attribute of the column 'ID'. {PK : INC : BIGINT : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_4702E7AF_BED5_430F_872C_0E616FCCB710]}
+     * PUBLIC.SYSTEM_SEQUENCE_50C4B525_E9F4_4DAA_B23A_A4E3F22E225B]}
      */
     protected Long _id;
 
@@ -330,14 +330,14 @@
     /**
      * The column annotation for S2Dao. {PK : INC : BIGINT : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_4702E7AF_BED5_430F_872C_0E616FCCB710]}
+     * PUBLIC.SYSTEM_SEQUENCE_50C4B525_E9F4_4DAA_B23A_A4E3F22E225B]}
      */
     public static final String id_COLUMN = "ID";
 
     /**
      * Get the value of the column 'ID'. <br /> {PK : INC : BIGINT : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_4702E7AF_BED5_430F_872C_0E616FCCB710]}
+     * PUBLIC.SYSTEM_SEQUENCE_50C4B525_E9F4_4DAA_B23A_A4E3F22E225B]}
      * 
      * @return The value of the column 'ID'. (Nullable)
      */
@@ -348,7 +348,7 @@
     /**
      * Set the value of the column 'ID'. <br /> {PK : INC : BIGINT : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_4702E7AF_BED5_430F_872C_0E616FCCB710]}
+     * PUBLIC.SYSTEM_SEQUENCE_50C4B525_E9F4_4DAA_B23A_A4E3F22E225B]}
      * 
      * @param id The value of the column 'ID'. (Nullable)
      */

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsEmployee.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsEmployee.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsEmployee.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -73,7 +73,7 @@
     /**
      * The attribute of the column 'ID'. {PK : INC : INTEGER : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_B9D70913_E2FA_457A_9EE2_47106722A258]}
+     * PUBLIC.SYSTEM_SEQUENCE_642A126C_91F0_49FA_A8A2_4B1D8067271C]}
      */
     protected Integer _id;
 
@@ -379,14 +379,14 @@
     /**
      * The column annotation for S2Dao. {PK : INC : INTEGER : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_B9D70913_E2FA_457A_9EE2_47106722A258]}
+     * PUBLIC.SYSTEM_SEQUENCE_642A126C_91F0_49FA_A8A2_4B1D8067271C]}
      */
     public static final String id_COLUMN = "ID";
 
     /**
      * Get the value of the column 'ID'. <br /> {PK : INC : INTEGER : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_B9D70913_E2FA_457A_9EE2_47106722A258]}
+     * PUBLIC.SYSTEM_SEQUENCE_642A126C_91F0_49FA_A8A2_4B1D8067271C]}
      * 
      * @return The value of the column 'ID'. (Nullable)
      */
@@ -397,7 +397,7 @@
     /**
      * Set the value of the column 'ID'. <br /> {PK : INC : INTEGER : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_B9D70913_E2FA_457A_9EE2_47106722A258]}
+     * PUBLIC.SYSTEM_SEQUENCE_642A126C_91F0_49FA_A8A2_4B1D8067271C]}
      * 
      * @param id The value of the column 'ID'. (Nullable)
      */

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsMonthlyReport.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsMonthlyReport.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsMonthlyReport.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -73,7 +73,7 @@
     /**
      * The attribute of the column 'ID'. {PK : INC : BIGINT : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_6A0692DE_1982_46B6_913E_4DD089ECE512]}
+     * PUBLIC.SYSTEM_SEQUENCE_32548B43_85E7_41E8_A673_8AE5B9803173]}
      */
     protected Long _id;
 
@@ -388,14 +388,14 @@
     /**
      * The column annotation for S2Dao. {PK : INC : BIGINT : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_6A0692DE_1982_46B6_913E_4DD089ECE512]}
+     * PUBLIC.SYSTEM_SEQUENCE_32548B43_85E7_41E8_A673_8AE5B9803173]}
      */
     public static final String id_COLUMN = "ID";
 
     /**
      * Get the value of the column 'ID'. <br /> {PK : INC : BIGINT : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_6A0692DE_1982_46B6_913E_4DD089ECE512]}
+     * PUBLIC.SYSTEM_SEQUENCE_32548B43_85E7_41E8_A673_8AE5B9803173]}
      * 
      * @return The value of the column 'ID'. (Nullable)
      */
@@ -406,7 +406,7 @@
     /**
      * Set the value of the column 'ID'. <br /> {PK : INC : BIGINT : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_6A0692DE_1982_46B6_913E_4DD089ECE512]}
+     * PUBLIC.SYSTEM_SEQUENCE_32548B43_85E7_41E8_A673_8AE5B9803173]}
      * 
      * @param id The value of the column 'ID'. (Nullable)
      */

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsUserInfo.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsUserInfo.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/BsUserInfo.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -19,7 +19,7 @@
  *     USER_ID
  * 
  * [column]
- *     USER_ID, GIVEN_NAME, FAMILY_NAME, MIDDLE_NAME, GIVEN_NAME_DESC, FAMILY_NAME_DESC, EMAIL, URL, TELEPHONE_NUMBER, ROLE_ID, GROUP_ID, CREATED_TIME, CREATED_BY, UPDATED_TIME, UPDATED_BY, DELETED_TIME, DELETED_BY, VERSIONNO
+ *     USER_ID, GIVEN_NAME, FAMILY_NAME, MIDDLE_NAME, GIVEN_NAME_DESC, FAMILY_NAME_DESC, EMAIL, URL, TELEPHONE, ROLE_ID, GROUP_ID, CREATED_TIME, CREATED_BY, UPDATED_TIME, UPDATED_BY, DELETED_TIME, DELETED_BY, VERSIONNO
  * 
  * [sequence]
  *     
@@ -92,8 +92,8 @@
     /** The attribute of the column 'URL'. {VARCHAR(255)} */
     protected String _url;
 
-    /** The attribute of the column 'TELEPHONE_NUMBER'. {VARCHAR(40)} */
-    protected String _telephoneNumber;
+    /** The attribute of the column 'TELEPHONE'. {VARCHAR(40)} */
+    protected String _telephone;
 
     /** The attribute of the column 'ROLE_ID'. {VARCHAR(255) : FK to ROLE_INFO} */
     protected String _roleId;
@@ -387,7 +387,7 @@
         sb.append(delimiter).append(getFamilyNameDesc());
         sb.append(delimiter).append(getEmail());
         sb.append(delimiter).append(getUrl());
-        sb.append(delimiter).append(getTelephoneNumber());
+        sb.append(delimiter).append(getTelephone());
         sb.append(delimiter).append(getRoleId());
         sb.append(delimiter).append(getGroupId());
         sb.append(delimiter).append(getCreatedTime());
@@ -590,26 +590,25 @@
     }
 
     /** The column annotation for S2Dao. {VARCHAR(40)} */
-    public static final String telephoneNumber_COLUMN = "TELEPHONE_NUMBER";
+    public static final String telephone_COLUMN = "TELEPHONE";
 
     /**
-     * Get the value of the column 'TELEPHONE_NUMBER'. <br /> {VARCHAR(40)}
+     * Get the value of the column 'TELEPHONE'. <br /> {VARCHAR(40)}
      * 
-     * @return The value of the column 'TELEPHONE_NUMBER'. (Nullable)
+     * @return The value of the column 'TELEPHONE'. (Nullable)
      */
-    public String getTelephoneNumber() {
-        return _telephoneNumber;
+    public String getTelephone() {
+        return _telephone;
     }
 
     /**
-     * Set the value of the column 'TELEPHONE_NUMBER'. <br /> {VARCHAR(40)}
+     * Set the value of the column 'TELEPHONE'. <br /> {VARCHAR(40)}
      * 
-     * @param telephoneNumber The value of the column 'TELEPHONE_NUMBER'.
-     *            (Nullable)
+     * @param telephone The value of the column 'TELEPHONE'. (Nullable)
      */
-    public void setTelephoneNumber(String telephoneNumber) {
-        _modifiedProperties.addPropertyName("telephoneNumber");
-        this._telephoneNumber = telephoneNumber;
+    public void setTelephone(String telephone) {
+        _modifiedProperties.addPropertyName("telephone");
+        this._telephone = telephone;
     }
 
     /** The column annotation for S2Dao. {VARCHAR(255) : FK to ROLE_INFO} */

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/dbmeta/UserInfoDbm.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/dbmeta/UserInfoDbm.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/bsentity/dbmeta/UserInfoDbm.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -68,8 +68,8 @@
     protected ColumnInfo _columnUrl = cci("URL", "url", String.class, false,
             255, 0);
 
-    protected ColumnInfo _columnTelephoneNumber = cci("TELEPHONE_NUMBER",
-            "telephoneNumber", String.class, false, 40, 0);
+    protected ColumnInfo _columnTelephone = cci("TELEPHONE", "telephone",
+            String.class, false, 40, 0);
 
     protected ColumnInfo _columnRoleId = cci("ROLE_ID", "roleId", String.class,
             false, 255, 0);
@@ -130,8 +130,8 @@
         return _columnUrl;
     }
 
-    public ColumnInfo columnTelephoneNumber() {
-        return _columnTelephoneNumber;
+    public ColumnInfo columnTelephone() {
+        return _columnTelephone;
     }
 
     public ColumnInfo columnRoleId() {
@@ -395,7 +395,7 @@
         setupEps(_epsMap, new EpsFamilyNameDesc(), columnFamilyNameDesc());
         setupEps(_epsMap, new EpsEmail(), columnEmail());
         setupEps(_epsMap, new EpsUrl(), columnUrl());
-        setupEps(_epsMap, new EpsTelephoneNumber(), columnTelephoneNumber());
+        setupEps(_epsMap, new EpsTelephone(), columnTelephone());
         setupEps(_epsMap, new EpsRoleId(), columnRoleId());
         setupEps(_epsMap, new EpsGroupId(), columnGroupId());
         setupEps(_epsMap, new EpsCreatedTime(), columnCreatedTime());
@@ -464,9 +464,9 @@
         }
     }
 
-    public static class EpsTelephoneNumber implements Eps<UserInfo> {
+    public static class EpsTelephone implements Eps<UserInfo> {
         public void setup(UserInfo e, Object v) {
-            e.setTelephoneNumber((String) v);
+            e.setTelephone((String) v);
         }
     }
 

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/bs/BsUserInfoCB.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/bs/BsUserInfoCB.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/bs/BsUserInfoCB.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -277,8 +277,8 @@
             doColumn("URL");
         }
 
-        public void columnTelephoneNumber() {
-            doColumn("TELEPHONE_NUMBER");
+        public void columnTelephone() {
+            doColumn("TELEPHONE");
         }
 
         public void columnRoleId() {

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsDailyReportCQ.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsDailyReportCQ.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsDailyReportCQ.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -50,7 +50,7 @@
     /**
      * Equal(=). And NullIgnored, OnceRegistered. {PK : INC : BIGINT : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_4702E7AF_BED5_430F_872C_0E616FCCB710]}
+     * PUBLIC.SYSTEM_SEQUENCE_50C4B525_E9F4_4DAA_B23A_A4E3F22E225B]}
      * 
      * @param id The value of id as equal.
      */

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsEmployeeCQ.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsEmployeeCQ.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsEmployeeCQ.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -52,7 +52,7 @@
     /**
      * Equal(=). And NullIgnored, OnceRegistered. {PK : INC : INTEGER : NotNull
      * : Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_B9D70913_E2FA_457A_9EE2_47106722A258]}
+     * PUBLIC.SYSTEM_SEQUENCE_642A126C_91F0_49FA_A8A2_4B1D8067271C]}
      * 
      * @param id The value of id as equal.
      */

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsMonthlyReportCQ.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsMonthlyReportCQ.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsMonthlyReportCQ.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -52,7 +52,7 @@
     /**
      * Equal(=). And NullIgnored, OnceRegistered. {PK : INC : BIGINT : NotNull :
      * Default=[NEXT VALUE FOR
-     * PUBLIC.SYSTEM_SEQUENCE_6A0692DE_1982_46B6_913E_4DD089ECE512]}
+     * PUBLIC.SYSTEM_SEQUENCE_32548B43_85E7_41E8_A673_8AE5B9803173]}
      * 
      * @param id The value of id as equal.
      */

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsUserInfoCQ.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/BsUserInfoCQ.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/BsUserInfoCQ.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -428,26 +428,26 @@
         return this;
     }
 
-    protected ConditionValue _telephoneNumber;
+    protected ConditionValue _telephone;
 
-    public ConditionValue getTelephoneNumber() {
-        if (_telephoneNumber == null) {
-            _telephoneNumber = new ConditionValue();
+    public ConditionValue getTelephone() {
+        if (_telephone == null) {
+            _telephone = new ConditionValue();
         }
-        return _telephoneNumber;
+        return _telephone;
     }
 
-    protected ConditionValue getCValueTelephoneNumber() {
-        return getTelephoneNumber();
+    protected ConditionValue getCValueTelephone() {
+        return getTelephone();
     }
 
-    public BsUserInfoCQ addOrderBy_TelephoneNumber_Asc() {
-        regOBA("TELEPHONE_NUMBER");
+    public BsUserInfoCQ addOrderBy_Telephone_Asc() {
+        regOBA("TELEPHONE");
         return this;
     }
 
-    public BsUserInfoCQ addOrderBy_TelephoneNumber_Desc() {
-        regOBD("TELEPHONE_NUMBER");
+    public BsUserInfoCQ addOrderBy_Telephone_Desc() {
+        regOBD("TELEPHONE");
         return this;
     }
 

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/ciq/UserInfoCIQ.java
===================================================================
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/ciq/UserInfoCIQ.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/ciq/UserInfoCIQ.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -184,8 +184,8 @@
         return _myCQ.getUrl();
     }
 
-    protected ConditionValue getCValueTelephoneNumber() {
-        return _myCQ.getTelephoneNumber();
+    protected ConditionValue getCValueTelephone() {
+        return _myCQ.getTelephone();
     }
 
     protected ConditionValue getCValueRoleId() {

Modified: timecard/trunk/src/main/webapp/WEB-INF/db/timecard.1.log.db
===================================================================
(Binary files differ)

Modified: timecard/trunk/src/main/webapp/WEB-INF/db/timecard.data.db
===================================================================
(Binary files differ)


pal-cvs メーリングリストの案内
Back to archive index
--- timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsUserInfoCQ.java	2008-11-06 06:30:25 UTC (rev 1294)
+++ timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/AbstractBsUserInfoCQ.java	2008-11-06 12:42:11 UTC (rev 1295)
@@ -1391,144 +1391,139 @@
     /**
      * Equal(=). And NullOrEmptyIgnored, OnceRegistered. {VARCHAR(40)}
      * 
-     * @param telephoneNumber The value of telephoneNumber as equal.
+     * @param telephone The value of telephone as equal.
      */
-    public void setTelephoneNumber_Equal(String telephoneNumber) {
-        regTelephoneNumber(CK_EQ, fRES(telephoneNumber));
+    public void setTelephone_Equal(String telephone) {
+        regTelephone(CK_EQ, fRES(telephone));
     }
 
     /**
      * NotEqual(!=). And NullOrEmptyIgnored, OnceRegistered.
      * 
-     * @param telephoneNumber The value of telephoneNumber as notEqual.
+     * @param telephone The value of telephone as notEqual.
      */
-    public void setTelephoneNumber_NotEqual(String telephoneNumber) {
-        regTelephoneNumber(CK_NE, fRES(telephoneNumber));
+    public void setTelephone_NotEqual(String telephone) {
+        regTelephone(CK_NE, fRES(telephone));
     }
 
     /**
      * GreaterThan(&gt;). And NullOrEmptyIgnored, OnceRegistered.
      * 
-     * @param telephoneNumber The value of telephoneNumber as greaterThan.
+     * @param telephone The value of telephone as greaterThan.
      */
-    public void setTelephoneNumber_GreaterThan(String telephoneNumber) {
-        regTelephoneNumber(CK_GT, fRES(telephoneNumber));
+    public void setTelephone_GreaterThan(String telephone) {
+        regTelephone(CK_GT, fRES(telephone));
     }
 
     /**
      * LessThan(&lt;). And NullOrEmptyIgnored, OnceRegistered.
      * 
-     * @param telephoneNumber The value of telephoneNumber as lessThan.
+     * @param telephone The value of telephone as lessThan.
      */
-    public void setTelephoneNumber_LessThan(String telephoneNumber) {
-        regTelephoneNumber(CK_LT, fRES(telephoneNumber));
+    public void setTelephone_LessThan(String telephone) {
+        regTelephone(CK_LT, fRES(telephone));
     }
 
     /**
      * GreaterEqual(&gt;=). And NullOrEmptyIgnored, OnceRegistered.
      * 
-     * @param telephoneNumber The value of telephoneNumber as greaterEqual.
+     * @param telephone The value of telephone as greaterEqual.
      */
-    public void setTelephoneNumber_GreaterEqual(String telephoneNumber) {
-        regTelephoneNumber(CK_GE, fRES(telephoneNumber));
+    public void setTelephone_GreaterEqual(String telephone) {
+        regTelephone(CK_GE, fRES(telephone));
     }
 
     /**
      * LessEqual(&lt;=). And NullOrEmptyIgnored, OnceRegistered.
      * 
-     * @param telephoneNumber The value of telephoneNumber as lessEqual.
+     * @param telephone The value of telephone as lessEqual.
      */
-    public void setTelephoneNumber_LessEqual(String telephoneNumber) {
-        regTelephoneNumber(CK_LE, fRES(telephoneNumber));
+    public void setTelephone_LessEqual(String telephone) {
+        regTelephone(CK_LE, fRES(telephone));
     }
 
     /**
      * PrefixSearch(like 'xxx%'). And NullOrEmptyIgnored, OnceRegistered.
      * 
-     * @param telephoneNumber The value of telephoneNumber as prefixSearch.
+     * @param telephone The value of telephone as prefixSearch.
      */
-    public void setTelephoneNumber_PrefixSearch(String telephoneNumber) {
-        regTelephoneNumber(CK_PS, fRES(telephoneNumber));
+    public void setTelephone_PrefixSearch(String telephone) {
+        regTelephone(CK_PS, fRES(telephone));
     }
 
     /**
      * LikeSearch(like 'xxx%' escape ...). And NullOrEmptyIgnored,
      * SeveralRegistered.
      * 
-     * @param telephoneNumber The value of telephoneNumber as likeSearch.
+     * @param telephone The value of telephone as likeSearch.
      * @param likeSearchOption The option of like-search. (NotNull)
      */
-    public void setTelephoneNumber_LikeSearch(
-            String telephoneNumber,
+    public void setTelephone_LikeSearch(
+            String telephone,
             jp.sf.pal.timecard.db.allcommon.cbean.coption.LikeSearchOption likeSearchOption) {
-        registerLikeSearchQuery(CK_LS, fRES(telephoneNumber),
-                getCValueTelephoneNumber(), "TELEPHONE_NUMBER",
-                "TelephoneNumber", "telephoneNumber", likeSearchOption);
+        registerLikeSearchQuery(CK_LS, fRES(telephone), getCValueTelephone(),
+                "TELEPHONE", "Telephone", "telephone", likeSearchOption);
     }
 
     /**
      * InScope(in ('a', 'b')). And NullOrEmptyIgnored,
      * NullOrEmptyElementIgnored, SeveralRegistered.
      * 
      * @param telephoneNumberList The collection of telephoneNumber as inScope.
      */
-    public void setTelephoneNumber_InScope(
-            Collection<String> telephoneNumberList) {
-        regTelephoneNumber(CK_INS, cTL(telephoneNumberList));
+    public void setTelephone_InScope(Collection<String> telephoneList) {
+        regTelephone(CK_INS, cTL(telephoneList));
     }
 
     /**
      * InScope(in ('a', 'b')). And NullOrEmptyIgnored,
      * NullOrEmptyElementIgnored, SeveralRegistered.
      * 
-     * @param telephoneNumber The collection of telephoneNumber as inScope.
+     * @param telephone The collection of telephone as inScope.
      * @param inScopeOption The option of in-scope. (NotNull)
      */
-    public void setTelephoneNumber_InScope(
-            String telephoneNumber,
+    public void setTelephone_InScope(
+            String telephone,
             jp.sf.pal.timecard.db.allcommon.cbean.coption.InScopeOption inScopeOption) {
-        registerInScopeQuery(CK_INS, fRES(telephoneNumber),
-                getCValueTelephoneNumber(), "TELEPHONE_NUMBER",
-                "TelephoneNumber", "telephoneNumber", inScopeOption);
+        registerInScopeQuery(CK_INS, fRES(telephone), getCValueTelephone(),
+                "TELEPHONE", "Telephone", "telephone", inScopeOption);
     }
 
     /**
      * NotInScope(not in ('a', 'b')). And NullOrEmptyIgnored,
      * NullOrEmptyElementIgnored, SeveralRegistered.
      * 
      * @param telephoneNumberList The collection of telephoneNumber as
      *            notInScope.
      */
-    public void setTelephoneNumber_NotInScope(
-            Collection<String> telephoneNumberList) {
-        regTelephoneNumber(CK_NINS, cTL(telephoneNumberList));
+    public void setTelephone_NotInScope(Collection<String> telephoneList) {
+        regTelephone(CK_NINS, cTL(telephoneList));
     }
 
     /**
      * IsNull(is null). And OnceRegistered.
      */
-    public void setTelephoneNumber_IsNull() {
-        regTelephoneNumber(CK_ISN, DUMMY_OBJECT);
+    public void setTelephone_IsNull() {
+        regTelephone(CK_ISN, DUMMY_OBJECT);
     }
 
     /**
      * IsNotNull(is not null). And OnceRegistered.
      */
-    public void setTelephoneNumber_IsNotNull() {
-        regTelephoneNumber(CK_ISNN, DUMMY_OBJECT);
+    public void setTelephone_IsNotNull() {
+        regTelephone(CK_ISNN, DUMMY_OBJECT);
     }
 
-    protected void regTelephoneNumber(ConditionKey key, Object value) {
-        registerQuery(key, value, getCValueTelephoneNumber(),
-                "TELEPHONE_NUMBER", "TelephoneNumber", "telephoneNumber");
+    protected void regTelephone(ConditionKey key, Object value) {
+        registerQuery(key, value, getCValueTelephone(), "TELEPHONE",
+                "Telephone", "telephone");
     }
 
-    protected void registerInlineTelephoneNumber(ConditionKey key, Object value) {
-        registerInlineQuery(key, value, getCValueTelephoneNumber(),
-                "TELEPHONE_NUMBER", "TelephoneNumber", "telephoneNumber");
+    protected void registerInlineTelephone(ConditionKey key, Object value) {
+        registerInlineQuery(key, value, getCValueTelephone(), "TELEPHONE",
+                "Telephone", "telephone");
     }
 
-    abstract protected ConditionValue getCValueTelephoneNumber();
+    abstract protected ConditionValue getCValueTelephone();
 
     /**
      * Equal(=). And NullOrEmptyIgnored, OnceRegistered. {VARCHAR(255) : FK to
@@ -1391,144 +1391,139 @@
      * NullOrEmptyElementIgnored, SeveralRegistered.
      * 
-     * @param telephoneNumberList The collection of telephoneNumber as inScope.
+     * @param telephoneList The collection of telephone as inScope.
      */
@@ -1391,144 +1391,139 @@
      * NullOrEmptyElementIgnored, SeveralRegistered.
      * 
-     * @param telephoneNumberList The collection of telephoneNumber as
-     *            notInScope.
+     * @param telephoneList The collection of telephone as notInScope.
      */

Modified: timecard/trunk/src/main/java/jp/sf/pal/timecard/db/cbean/cq/bs/BsUserInfoCQ.java
===================================================================